#################################
#### Code to generate FigS10 ####
#################################

#### Load required packages
import numpy as np
from scipy import stats
import random
import cmocean
import matplotlib.pyplot as plt
import matplotlib.gridspec as gridspec
from matplotlib import rc
import matplotlib as mpl
from matplotlib.colorbar import Colorbar
from copy import deepcopy
import matplotlib.colors

#### Load data
array_incu_infector = np.load("../data/array_incubation_infector_censored.npy", allow_pickle=True)
array_incu_infectee = np.load("../data/array_incubation_infectee_censored.npy", allow_pickle=True)

#### set the colormap and centre the colorbar
class MidpointNormalize(matplotlib.colors.Normalize):
	"""
	Normalise the colorbar so that diverging bars work there way either side from a prescribed midpoint value)

	e.g. im=ax1.imshow(array, norm=MidpointNormalize(midpoint=0.,vmin=-100, vmax=100))
	"""
	def __init__(self, vmin=None, vmax=None, midpoint=None, clip=False):
		self.midpoint = midpoint
		matplotlib.colors.Normalize.__init__(self, vmin, vmax, clip)

	def __call__(self, value, clip=None):
		# I'm ignoring masked values and all kinds of edge cases to make a
		# simple example...
		x, y = [self.vmin, self.midpoint, self.vmax], [0, 0.5, 1]
		return np.ma.masked_array(np.interp(value, x, y), np.isnan(value))
from pylab import meshgrid
import seaborn as sns

temp_x = []
temp_y = []

for i in range(100):
    temp_x += list(array_incu_infector[i])
    temp_y += list(array_incu_infectee[i])

incu_kernel_imp = stats.gaussian_kde([temp_x, temp_y])
def weight_func(x, y):
    p_kernel_2d_imp = incu_kernel_imp([x, y])
    p_incu_infector = stats.weibull_min.pdf(x, 1.578104 , scale=7.112123)
    p_incu_infectee = stats.weibull_min.pdf(y, 1.578104 , scale=7.112123)
    return(p_incu_infector*p_incu_infectee/p_kernel_2d_imp[0])

x_list = np.arange(0.5, 30.5, .5)
y_list = np.arange(0.5, 25.5, .5)
X, Y = meshgrid(x_list, y_list)
Z = X
list_weights = []
for i in range(len(X)):
    for j in range(len(X[0])):
        if weight_func(X[i][j], Y[i][j]) != 0:
            Z[i][j] = np.log10(weight_func(X[i][j], Y[i][j]))
        else:
            Z[i][j] = np.nan
        list_weights.append(Z[i][j])

fig, ax = plt.subplots(figsize=(5, 4))
ax.scatter(temp_x, temp_y, s=0.05, color=".6")


heatmap = ax.imshow(Z, cmap=cmocean.cm.balance, origin="lower", aspect="auto", extent=[0, 30, 0, 25], norm=MidpointNormalize(midpoint=0,vmin=min(list_weights), vmax=max(list_weights)), interpolation="gaussian")
cbar = fig.colorbar(heatmap, ax=ax, shrink=0.7, label="log10(weight)")
cbar.ax.set_ylabel(cbar.ax.get_ylabel(), rotation=270, labelpad=10)
ax.set_xlabel("incubation period infector (days)")
ax.set_ylabel("incubation period infectee (days)")
plt.tight_layout()
plt.savefig("../plots/FigS11.pdf", format="pdf")